@@ -5,20 +5,20 @@
 # automate several Nextcloud features.
 #
 # MIT License
-# 
+#
 # Copyright (C) 2022 Barcelona Supercomputing Center, José M. Fernández
 # Copyright (c) 2022 Spanish National Bioinformatics Institute
-# 
+#
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
 # in the Software without restriction, including without limitation the rights
 # to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 # copies of the Software, and to permit persons to whom the Software is
 # furnished to do so, subject to the following conditions:
-# 
+#
 # The above copyright notice and this permission notice shall be included in all
 # copies or substantial portions of the Software.
-# 
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 # IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -27,9 +27,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-__author__ = 'José M. Fernández <https://orcid.org/0000-0002-4806-5140>'
-__copyright__ = '© 2022 Barcelona Supercomputing Center (BSC), ES'
-__license__ = 'MIT'
+__author__ = "José M. Fernández <https://orcid.org/0000-0002-4806-5140>"
+__copyright__ = "© 2022 Barcelona Supercomputing Center (BSC), ES"
+__license__ = "MIT"
 
 # https://www.python.org/dev/peps/pep-0396/
-__version__ = '0.1.1'
+__version__ = "0.1.2"
